fn fuzz_test_path_name<'a>(
abi: &JsonAbi,
func: &'a Function,
config: &FuzzConfig,
contract_name: &str,
) -> Cow<'a, str>Expand description
Returns a stable path component that distinguishes overloaded fuzz tests.
fn fuzz_test_path_name<'a>(
abi: &JsonAbi,
func: &'a Function,
config: &FuzzConfig,
contract_name: &str,
) -> Cow<'a, str>Returns a stable path component that distinguishes overloaded fuzz tests.