fn same_sequence_failure(
actual: &CheckSequenceOutcome,
expected: &CheckSequenceOutcome,
) -> boolExpand description
Returns true if two sequence replays failed in the same way at the same site.
fn same_sequence_failure(
actual: &CheckSequenceOutcome,
expected: &CheckSequenceOutcome,
) -> boolReturns true if two sequence replays failed in the same way at the same site.