type SymbolicHandlerStorageMap = HashMap<(Address, Selector, B256), SymbolicHandlerReplayStorage>;Expand description
Symbolic replay storage for handler bugs keyed by (reverter, selector, fingerprint).
Aliased Type
struct SymbolicHandlerStorageMap { /* private fields */ }Layout
Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.
Size: 40 bytes