fn persisted_call_sequence(
path: &Path,
current_settings: &InvariantSettings,
) -> Option<Vec<BaseCounterExample>>Expand description
Helper function to load failed call sequence from file. Ignores failure if generated with different invariant settings than the current ones.